
import requests
import os


def upload(metric_name="", metric_value="", metric_explain=""):
    token = os.getenv('EVALUATION_TOKEN')
    evaluation_id = os.getenv('EVALUATION_JOB_ID')
    hook_svc = os.getenv('HOOK_URL')
    if token == "":
        print("get token failed!")
        return False

    if evaluation_id == "":
        print("get evaluation_id failed!")
        return False

    if hook_svc == "":
        print("get hook_url failed!")
        return False

    headers = {
        "Authorization": f"Bearer {token}",
        "Content-Type": "application/json"
    }

    if not metric_name:
        print("metric name is required!")
        return False

    if not metric_value:
        print("metric value is required!")
        return False

    json_data = {
        "evaluationId": evaluation_id,
        "columnKey": metric_name,
        "columnExplain": metric_explain,
        "contents": metric_value
    }

    response = requests.post(hook_svc, headers=headers, json=json_data, verify=False)

    if response.status_code == 200:
        json_response = response.json()
        # print(json_data)  # 打印响应的 JSON 数据
        if json_response.get('success'):
            return True
        else:
            print(f"Failed. msg: {json_response['error']['message']}")
            return False
    else:
        print(f"Failed. Status code: {response.status_code}")
        return False


if __name__ == "__main__":
    upload("ceshi", "测试", "一个测试指标")



from setuptools import setup, find_packages

setup(
    name="model_metrics_upload",                # 包的名称，pip安装时用到
    version="1.0.1",                  # 版本号
    author="admin",               # 作者名称
    author_email="111@google.com",  # 作者邮箱
    description="upload model params to target address", # 简短描述
    long_description=open('README.md').read(), # 从 README.md 中读取长描述
    long_description_content_type='text/markdown', # 指定 README 文件的格式
    url="", # 项目主页
    packages=find_packages(),         # 自动发现包
    classifiers=[                     # 其他元数据
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',          # 指定 Python 版本要求
    install_requires=[                # 依赖的库
        "requests",
    ],
)